;Project Lynxmotion Phoenix
;Description: 3DOF T-Hex, configuration file.
;      All Hardware connections (excl controls) and body dimensions 
;      are configurated in this file. Can be used with V2.1 and above
;Configuration version: V1.1 alfa
;Date: April 15, 2011
;Programmers: Jeroen Janssen (aka Xan)
;			  Kre Halvorsen (aka Zenta)
;
;Hardware setup: ABB2 with ATOM 28 Pro, SSC32 V2, (See further for connections)
;
;NEW IN V1.1
;   - Added speaker constant
;	- Added support for different leg lengths
;	- Optional 4DOF
;	- Optional Safety shut down when voltage drops
;
;--------------------------------------------------------------------
;[CONDITIONAL COMPILING] - COMMENT IF NOT WANTED
;c4DOF			 con 1	 	; Switch between 3DOF and 4DOF
;cTurnOffVol	 con 630 	; When uncomment the bot will turn off when 
							; the voltage drops below this setpoint (630 = 6.3V)
cNoGP			 con 1		; turn of GP player
cNoSL			 con 1		; turn off single leg control
ApodCode		 con 1
							
USEPS2			con 1
;--------------------------------------------------------------------
;[SERIAL CONNECTIONS]
#ifdef BASICATOMPRO28
cSSC_OUT        con P11     ;Output pin for (SSC32 RX) on BotBoard (Yellow)
cSSC_IN         con P10     ;Input pin for (SSC32 TX) on BotBoard (Blue)
cSSC_BAUD       con i115200	;SSC32 BAUD rate 38400 115200
;--------------------------------------------------------------------
;[BB2 PIN NUMBERS]
; Note the default PS2 definitions are in the PS2 control file.
;cXBEE_RTS		con P7			; for XBee version
;PS2DAT 			con P16		;PS2 Controller DAT (Brown)
;PS2CMD 			con P17		;PS2 controller CMD (Orange)
;PS2SEL 			con P18		;PS2 Controller SEL (Blue)
;PS2CLK 			con P19		;PS2 Controller CLK (White)
cEyesPin      	con P8
cSpeakerPin		con P9
cVoltagePin		con 17		; Defines the analog input to read the voltage

#else
cSSC_OUT        con P11     ;Output pin for (SSC32 RX) on BotBoard (Yellow)
cSSC_IN         con P10     ;Input pin for (SSC32 TX) on BotBoard (Blue)
cSSC_BAUD       con i115200	;SSC32 BAUD rate 38400 115200

cEyesPin      	con P0
cSpeakerPin		con P5
//cVoltagePin		con 33		; Defines the analog input to read the voltage warning other command...

PS2DAT 			con P40		;PS2 Controller DAT (Brown)
PS2CMD 			con P41		;PS2 controller CMD (Orange)
PS2SEL 			con P42		;PS2 Controller SEL (Blue)
PS2CLK 			con P43		;PS2 Controller CLK (White)
#endif

							; for safety shutdown. (16=AX0=VS, 17=AX1=VL) 
;--------------------------------------------------------------------
;[SSC PIN NUMBERS]
cRFCoxaPin      con P0   ;Rear Right leg Hip Horizontal
cRFFemurPin    	con P1   ;Rear Right leg Hip Vertical
cRFTibiaPin    	con P2   ;Rear Right leg Knee
cRFTarsPin		con P3	 ;Rear Right leg foot

cRMCoxaPin      con P4   ;Middle Right leg Hip Horizontal
cRMFemurPin    	con P5   ;Middle Right leg Hip Vertical
cRMTibiaPin    	con P6   ;Middle Right leg Knee
cRMTarsPin		con P7	 ;Middle Right leg foot

cRRCoxaPin      con P8   ;Front Right leg Hip Horizontal
cRRFemurPin    	con P9   ;Front Right leg Hip Vertical
cRRTibiaPin    	con P10  ;Front Right leg Knee
cRRTarsPin		con P11  ;Front Right leg foot

cLFCoxaPin      con P16  ;Rear Left leg Hip Horizontal
cLFFemurPin    	con P17  ;Rear Left leg Hip Vertical
cLFTibiaPin    	con P18  ;Rear Left leg Knee
cLFTarsPin		con P19	 ;Rear Left leg foot

cLMCoxaPin      con P20   ;Middle Left leg Hip Horizontal
cLMFemurPin    	con P21   ;Middle Left leg Hip Vertical
cLMTibiaPin    	con P22   ;Middle Left leg Knee
cLMTarsPin		con P23	  ;Middle Left leg foot

cLRCoxaPin      con P24   ;Front Left leg Hip Horizontal
cLRFemurPin    	con P25   ;Front Left leg Hip Vertical
cLRTibiaPin    	con P26   ;Front Left leg Knee
cLRTarsPin		con P27	  ;Front Left leg foot

cHeadRotPin		con P13	;Head Rotate
cHeadPanPin		con	P12	;Head Panorate (side to side)
cHeadTiltPin	con P14	;Head Tilt (up and down)

cMandRightPin 	con P28;Right Mandible
cMandLeftPin 	con P29;Left Mandible

cAbdomPanPin	con P30;Abdomen Panorate (tail side to side)
cAbdomTiltPin 	con P31;Abdomen Tilt (tail up and down)	


;--------------------------------------------------------------------
;[Joint offsets]
;First calibrate the servos in the 0 deg position using the SSC-32 reg offsets, then:
cXXFemurHornOffset	con 0 ;Default no servo horn offsets
cXXTarsHornOffset	con 0 ; 

; Set up to have per leg offsets...
cRRFemurHornOffset1	con cXXFemurHornOffset
cRRTarsHornOffset1	con cXXTarsHornOffset	

cRMFemurHornOffset1	con cXXFemurHornOffset
cRMTarsHornOffset1	con cXXTarsHornOffset	

cRFFemurHornOffset1	con cXXFemurHornOffset
cRFTarsHornOffset1	con cXXTarsHornOffset	

cLRFemurHornOffset1	con cXXFemurHornOffset
cLRTarsHornOffset1	con cXXTarsHornOffset	

cLMFemurHornOffset1	con cXXFemurHornOffset
cLMTarsHornOffset1	con cXXTarsHornOffset	

cLFFemurHornOffset1	con cXXFemurHornOffset
cLFTarsHornOffset1	con cXXTarsHornOffset	


;--------------------------------------------------------------------
;[MIN/MAX ANGLES]
cRRCoxaMIN1	con -560		;Mechanical limits of the Right Rear Leg
cRRCoxaMAX1	con 930
cRRFemurMIN1	con -1050
cRRFemurMAX1	con 750
cRRTibiaMIN1	con -680
cRRTibiaMAX1	con 900
cRRTarsMin1		con -1300	  ;4DOF ONLY - In theory the kinematics can reach about -160 deg
cRRTarsMax1		con 500		  ;4DOF ONLY - The kinematics will never exceed 23 deg though..

cRMCoxaMIN1	con -500		;Mechanical limits of the Right Middle Leg
cRMCoxaMAX1	con 500
cRMFemurMIN1	con -1050
cRMFemurMAX1	con 750
cRMTibiaMIN1	con -680
cRMTibiaMAX1	con 900
cRMTarsMin1		con -1300	  ;4DOF ONLY
cRMTarsMax1		con 500	  	  ;4DOF ONLY

cRFCoxaMIN1	con -950		;Mechanical limits of the Right Front Leg
cRFCoxaMAX1	con 620
cRFFemurMIN1	con -1050
cRFFemurMAX1	con 750
cRFTibiaMIN1	con -680
cRFTibiaMAX1	con 900
cRFTarsMin1		con -1300	  ;4DOF ONLY
cRFTarsMax1		con 500	      ;4DOF ONLY

cLRCoxaMIN1	con -930	;Mechanical limits of the Left Rear Leg
cLRCoxaMAX1	con 560
cLRFemurMIN1	con -1050
cLRFemurMAX1	con 750
cLRTibiaMIN1	con -680
cLRTibiaMAX1	con 900
cLRTarsMin1		con -1300	  ;4DOF ONLY
cLRTarsMax1		con 500	      ;4DOF ONLY

cLMCoxaMIN1	con -500		;Mechanical limits of the Left Middle Leg
cLMCoxaMAX1	con 500
cLMFemurMIN1	con -1050
cLMFemurMAX1	con 750
cLMTibiaMIN1	con -680
cLMTibiaMAX1	con 900
cLMTarsMin1		con -1300	  ;4DOF ONLY
cLMTarsMax1		con 500	      ;4DOF ONLY

cLFCoxaMIN1	con -620		;Mechanical limits of the Left Front Leg
cLFCoxaMAX1	con 950
cLFFemurMIN1	con -1050
cLFFemurMAX1	con 750
cLFTibiaMIN1	con -680
cLFTibiaMAX1	con 900
cLFTarsMin1		con -1300	  ;4DOF ONLY
cLFTarsMax1		con 500	      ;4DOF ONLY

;Mechanical limits of Head Rotate
cHeadRotMAX1	con	1420
cHeadRotMIN1	con	-450

;Mechanical limits of Head Panorate (side to side)
cHeadPanMAX1	con	380
cHeadPanMIN1	con	-380

;Mechanical limits of Head Tilt (up and down)
cHeadTiltMAX1 	con	600
cHeadTiltMIN1 	con	-530

;Mechanical limits of Right Mandible
cMandRightMAX1	con	600
cMandRightMIN1	con	-280

;Mechanical limits of Left Mandible (reversed in SEQ, not here!)
cMandLeftMAX1	con	600
cMandLeftMIN1	con	-280

;Mechanical limits of Abdomen Tilt (tail up and down)
cAbdomTiltMAX1 	con	620
cAbdomTiltMIN1 	con	-580

;Mechanical limits of Abdomen Panorate (tail side to side)
cAbdomPanMAX1	con	360
cAbdomPanMIN1	con	-360


;--------------------------------------------------------------------
;[LEG DIMENSIONS]
;Universal dimensions for each leg
cXXCoxaLength  	con 42		;Length of the Coxa [mm]
cXXFemurLength 	con 80		;Length of the Femur [mm]
cXXTibiaLength 	con 120		;Lenght of the Tibia [mm]
cXXTarsLength	con	85		;4DOF ONLY - Lenght of the Tars [mm]

cRRCoxaLength   con cXXCoxaLength	;Rigth Rear leg
cRRFemurLength  con cXXFemurLength
cRRTibiaLength  con cXXTibiaLength
cRRTarsLength	con cXXTarsLength	;4DOF ONLY

cRMCoxaLength   con cXXCoxaLength	;Rigth middle leg
cRMFemurLength  con cXXFemurLength
cRMTibiaLength  con cXXTibiaLength
cRMTarsLength	con cXXTarsLength	;4DOF ONLY

cRFCoxaLength   con cXXCoxaLength	;Rigth front leg
cRFFemurLength  con cXXFemurLength
cRFTibiaLength  con cXXTibiaLength
cRFTarsLength	con cXXTarsLength	;4DOF ONLY

cLRCoxaLength   con cXXCoxaLength	;Left Rear leg
cLRFemurLength  con cXXFemurLength
cLRTibiaLength  con cXXTibiaLength
cLRTarsLength	con cXXTarsLength	;4DOF ONLY

cLMCoxaLength   con cXXCoxaLength	;Left middle leg
cLMFemurLength  con cXXFemurLength
cLMTibiaLength  con cXXTibiaLength
cLMTarsLength	con cXXTarsLength	;4DOF ONLY

cLFCoxaLength   con cXXCoxaLength	;Left front leg
cLFFemurLength  con cXXFemurLength
cLFTibiaLength  con cXXTibiaLength
cLFTarsLength	con cXXTarsLength	;4DOF ONLY
;--------------------------------------------------------------------
;[BODY DIMENSIONS]
cRRCoxaAngle1 	con -450	;Default Coxa setup angle, decimals = 1
cRMCoxaAngle1 	con 0		;Default Coxa setup angle, decimals = 1
cRFCoxaAngle1 	con 450		;Default Coxa setup angle, decimals = 1
cLRCoxaAngle1 	con -450	;Default Coxa setup angle, decimals = 1
cLMCoxaAngle1 	con 0		;Default Coxa setup angle, decimals = 1
cLFCoxaAngle1 	con 450		;Default Coxa setup angle, decimals = 1

cRROffsetX 		con -71		;Distance X from center of the body to the Right Rear coxa
cRROffsetZ 		con 85		;Distance Z from center of the body to the Right Rear coxa
cRMOffsetX 		con -71		;Distance X from center of the body to the Right Middle coxa
cRMOffsetZ 		con 0		;Distance Z from center of the body to the Right Middle coxa
cRFOffsetX 		con -71		;Distance X from center of the body to the Right Front coxa
cRFOffsetZ 		con -85		;Distance Z from center of the body to the Right Front coxa

cLROffsetX 		con 71		;Distance X from center of the body to the Left Rear coxa
cLROffsetZ 		con 85		;Distance Z from center of the body to the Left Rear coxa
cLMOffsetX 		con 71		;Distance X from center of the body to the Left Middle coxa
cLMOffsetZ 		con 0		;Distance Z from center of the body to the Left Middle coxa
cLFOffsetX 		con 71		;Distance X from center of the body to the Left Front coxa
cLFOffsetZ 		con -85		;Distance Z from center of the body to the Left Front coxa

;--------------------------------------------------------------------
;[START POSITIONS FEET]
cHexInitPosY   	con 26	   ;Global start hight
cHexInitXZ		con 98

CHexInitY		con 15

cRRInitPosX 	con 69		;Start positions of the Right Rear leg
cRRInitPosY 	con CHexInitY
cRRInitPosZ 	con 69

cRMInitPosX 	con 98		;Start positions of the Right Middle leg
cRMInitPosY 	con CHexInitY
cRMInitPosZ 	con 0

cRFInitPosX 	con 69		;Start positions of the Right Front leg
cRFInitPosY 	con CHexInitY
cRFInitPosZ 	con -69

cLRInitPosX 	con 69		;Start positions of the Left Rear leg
cLRInitPosY 	con CHexInitY
cLRInitPosZ 	con 69

cLMInitPosX 	con 98		;Start positions of the Left Middle leg
cLMInitPosY 	con CHexInitY
cLMInitPosZ 	con 0

cLFInitPosX 	con 69		;Start positions of the Left Front leg
cLFInitPosY 	con CHexInitY
cLFInitPosZ 	con -69

;--------------------------------------------------------------------
;[Tars factors used in formula to calc Tarsus angle relative to the ground]
cTarsConst		con	720	;4DOF ONLY
cTarsMulti		con 2	;4DOF ONLY
cTarsFactorA	con 70	;4DOF ONLY
cTarsFactorB	con 60	;4DOF ONLY
cTarsFactorC	con 50	;4DOF ONLY
;--------------------------------------------------------------------
;-------------------------------------------------------------------------
;[Servo PWM values] Center (0 deg), max and min deg
; *** NOT USED YET *** FEIL verdier bruk PEP metoden, dvs bruk reversed verdier
cHeadRotPWM			con 1138	;Head Rotate
cHeadRotMaxPWM		con	2500
cHeadRotMinPWM		con	714

cHeadPanPWM			con	1489	;Head Panorate (side to side)
cHeadPanMaxPWM		con	1911
cHeadPanMinPWM		con	1065

cHeadTiltPWM 		con 1218	;Head Tilt (up and down)
cHeadTiltMaxPWM 		con	1987
cHeadTiltMinPWM 		con	766

cMandRightClosedPWM	con 1124	;Right Mandible
cMandRightMaxPWM		con	2052
cMandRightMinPWM		con	1098

cMandLeftClosedPWM	con	1836	;Left Mandible (reversed in SEQ, not here!)
cMandLeftMaxPWM		con	1861
cMandLeftminPWM		con	949

cAbdomTiltPWM 		con 1511	;Abdomen Tilt (tail up and down)
cAbdomTiltMaxPWM 	con	2142
cAbdomTiltMinPWM 	con	907

cAbdomPanPWM			con	1453	;Abdomen Panorate (tail side to side)
cAbdomPanMaxPWM		con	1860
cAbdomPanMinPWM		con	1046